# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKBinaryMathematicalMorphologyPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkDilateObjectMorphologyImageFilterPython
else:
    import _itkDilateObjectMorphologyImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkFlatStructuringElementPython
import itk.itkNeighborhoodPython
import itk.itkRGBPixelPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkBoxImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkIndexPython
import itk.itkImageRegionPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageBoundaryConditionPython
class itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetKernel(self, _arg):
        r"""
        SetKernel(self, _arg)

        Parameters
        ----------
        _arg: itkFlatStructuringElement2

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_SetKernel(self, _arg)

    def GetKernel(self):
        r"""GetKernel(self) -> itkFlatStructuringElement2"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_GetKernel(self)

    def GetObjectValue(self):
        r"""GetObjectValue(self) -> float"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_GetObjectValue(self)

    def SetObjectValue(self, _arg):
        r"""
        SetObjectValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_SetObjectValue(self, _arg)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_GenerateInputRequestedRegion(self)

    def OverrideBoundaryCondition(self, i):
        r"""
        OverrideBoundaryCondition(self, i)

        Parameters
        ----------
        i: itkImageBoundaryConditionIF2 *const

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_OverrideBoundaryCondition(self, i)

    def ResetBoundaryCondition(self):
        r"""ResetBoundaryCondition(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_ResetBoundaryCondition(self)

    def GetBoundaryCondition(self):
        r"""GetBoundaryCondition(self) -> itkImageBoundaryConditionIF2"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_GetBoundaryCondition(self)

    def SetUseBoundaryCondition(self, _arg):
        r"""
        SetUseBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_SetUseBoundaryCondition(self, _arg)

    def GetUseBoundaryCondition(self):
        r"""GetUseBoundaryCondition(self) -> bool"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_GetUseBoundaryCondition(self)
    SameDimensionCheck1 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_SameDimensionCheck2
    
    OutputInputEqualityComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_OutputInputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_InputConvertibleToOutputCheck
    
    IntConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_IntConvertibleToOutputCheck
    
    InputEqualityComparable = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_InputEqualityComparable
    
    InputOStreamWritableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_InputOStreamWritableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_cast(obj)

# Register itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass_swigregister(itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass)
class itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetKernel(self, _arg):
        r"""
        SetKernel(self, _arg)

        Parameters
        ----------
        _arg: itkFlatStructuringElement3

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_SetKernel(self, _arg)

    def GetKernel(self):
        r"""GetKernel(self) -> itkFlatStructuringElement3"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_GetKernel(self)

    def GetObjectValue(self):
        r"""GetObjectValue(self) -> float"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_GetObjectValue(self)

    def SetObjectValue(self, _arg):
        r"""
        SetObjectValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_SetObjectValue(self, _arg)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_GenerateInputRequestedRegion(self)

    def OverrideBoundaryCondition(self, i):
        r"""
        OverrideBoundaryCondition(self, i)

        Parameters
        ----------
        i: itkImageBoundaryConditionIF3 *const

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_OverrideBoundaryCondition(self, i)

    def ResetBoundaryCondition(self):
        r"""ResetBoundaryCondition(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_ResetBoundaryCondition(self)

    def GetBoundaryCondition(self):
        r"""GetBoundaryCondition(self) -> itkImageBoundaryConditionIF3"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_GetBoundaryCondition(self)

    def SetUseBoundaryCondition(self, _arg):
        r"""
        SetUseBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_SetUseBoundaryCondition(self, _arg)

    def GetUseBoundaryCondition(self):
        r"""GetUseBoundaryCondition(self) -> bool"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_GetUseBoundaryCondition(self)
    SameDimensionCheck1 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_SameDimensionCheck2
    
    OutputInputEqualityComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_OutputInputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_InputConvertibleToOutputCheck
    
    IntConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_IntConvertibleToOutputCheck
    
    InputEqualityComparable = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_InputEqualityComparable
    
    InputOStreamWritableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_InputOStreamWritableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_cast(obj)

# Register itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass_swigregister(itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass)
class itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetKernel(self, _arg):
        r"""
        SetKernel(self, _arg)

        Parameters
        ----------
        _arg: itkFlatStructuringElement2

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_SetKernel(self, _arg)

    def GetKernel(self):
        r"""GetKernel(self) -> itkFlatStructuringElement2"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_GetKernel(self)

    def GetObjectValue(self):
        r"""GetObjectValue(self) -> short"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_GetObjectValue(self)

    def SetObjectValue(self, _arg):
        r"""
        SetObjectValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_SetObjectValue(self, _arg)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_GenerateInputRequestedRegion(self)

    def OverrideBoundaryCondition(self, i):
        r"""
        OverrideBoundaryCondition(self, i)

        Parameters
        ----------
        i: itkImageBoundaryConditionISS2 *const

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_OverrideBoundaryCondition(self, i)

    def ResetBoundaryCondition(self):
        r"""ResetBoundaryCondition(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_ResetBoundaryCondition(self)

    def GetBoundaryCondition(self):
        r"""GetBoundaryCondition(self) -> itkImageBoundaryConditionISS2"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_GetBoundaryCondition(self)

    def SetUseBoundaryCondition(self, _arg):
        r"""
        SetUseBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_SetUseBoundaryCondition(self, _arg)

    def GetUseBoundaryCondition(self):
        r"""GetUseBoundaryCondition(self) -> bool"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_GetUseBoundaryCondition(self)
    SameDimensionCheck1 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_SameDimensionCheck2
    
    OutputInputEqualityComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_OutputInputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_InputConvertibleToOutputCheck
    
    IntConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_IntConvertibleToOutputCheck
    
    InputEqualityComparable = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_InputEqualityComparable
    
    InputOStreamWritableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_InputOStreamWritableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_cast(obj)

# Register itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass_swigregister(itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass)
class itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetKernel(self, _arg):
        r"""
        SetKernel(self, _arg)

        Parameters
        ----------
        _arg: itkFlatStructuringElement3

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_SetKernel(self, _arg)

    def GetKernel(self):
        r"""GetKernel(self) -> itkFlatStructuringElement3"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_GetKernel(self)

    def GetObjectValue(self):
        r"""GetObjectValue(self) -> short"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_GetObjectValue(self)

    def SetObjectValue(self, _arg):
        r"""
        SetObjectValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_SetObjectValue(self, _arg)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_GenerateInputRequestedRegion(self)

    def OverrideBoundaryCondition(self, i):
        r"""
        OverrideBoundaryCondition(self, i)

        Parameters
        ----------
        i: itkImageBoundaryConditionISS3 *const

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_OverrideBoundaryCondition(self, i)

    def ResetBoundaryCondition(self):
        r"""ResetBoundaryCondition(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_ResetBoundaryCondition(self)

    def GetBoundaryCondition(self):
        r"""GetBoundaryCondition(self) -> itkImageBoundaryConditionISS3"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_GetBoundaryCondition(self)

    def SetUseBoundaryCondition(self, _arg):
        r"""
        SetUseBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_SetUseBoundaryCondition(self, _arg)

    def GetUseBoundaryCondition(self):
        r"""GetUseBoundaryCondition(self) -> bool"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_GetUseBoundaryCondition(self)
    SameDimensionCheck1 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_SameDimensionCheck2
    
    OutputInputEqualityComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_OutputInputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_InputConvertibleToOutputCheck
    
    IntConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_IntConvertibleToOutputCheck
    
    InputEqualityComparable = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_InputEqualityComparable
    
    InputOStreamWritableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_InputOStreamWritableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_cast(obj)

# Register itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass_swigregister(itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass)
class itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetKernel(self, _arg):
        r"""
        SetKernel(self, _arg)

        Parameters
        ----------
        _arg: itkFlatStructuringElement2

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_SetKernel(self, _arg)

    def GetKernel(self):
        r"""GetKernel(self) -> itkFlatStructuringElement2"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_GetKernel(self)

    def GetObjectValue(self):
        r"""GetObjectValue(self) -> unsigned char"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_GetObjectValue(self)

    def SetObjectValue(self, _arg):
        r"""
        SetObjectValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_SetObjectValue(self, _arg)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_GenerateInputRequestedRegion(self)

    def OverrideBoundaryCondition(self, i):
        r"""
        OverrideBoundaryCondition(self, i)

        Parameters
        ----------
        i: itkImageBoundaryConditionIUC2 *const

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_OverrideBoundaryCondition(self, i)

    def ResetBoundaryCondition(self):
        r"""ResetBoundaryCondition(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_ResetBoundaryCondition(self)

    def GetBoundaryCondition(self):
        r"""GetBoundaryCondition(self) -> itkImageBoundaryConditionIUC2"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_GetBoundaryCondition(self)

    def SetUseBoundaryCondition(self, _arg):
        r"""
        SetUseBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_SetUseBoundaryCondition(self, _arg)

    def GetUseBoundaryCondition(self):
        r"""GetUseBoundaryCondition(self) -> bool"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_GetUseBoundaryCondition(self)
    SameDimensionCheck1 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_SameDimensionCheck2
    
    OutputInputEqualityComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_OutputInputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_InputConvertibleToOutputCheck
    
    IntConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_IntConvertibleToOutputCheck
    
    InputEqualityComparable = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_InputEqualityComparable
    
    InputOStreamWritableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_InputOStreamWritableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_cast(obj)

# Register itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass_swigregister(itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass)
class itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetKernel(self, _arg):
        r"""
        SetKernel(self, _arg)

        Parameters
        ----------
        _arg: itkFlatStructuringElement3

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_SetKernel(self, _arg)

    def GetKernel(self):
        r"""GetKernel(self) -> itkFlatStructuringElement3"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_GetKernel(self)

    def GetObjectValue(self):
        r"""GetObjectValue(self) -> unsigned char"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_GetObjectValue(self)

    def SetObjectValue(self, _arg):
        r"""
        SetObjectValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_SetObjectValue(self, _arg)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_GenerateInputRequestedRegion(self)

    def OverrideBoundaryCondition(self, i):
        r"""
        OverrideBoundaryCondition(self, i)

        Parameters
        ----------
        i: itkImageBoundaryConditionIUC3 *const

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_OverrideBoundaryCondition(self, i)

    def ResetBoundaryCondition(self):
        r"""ResetBoundaryCondition(self)"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_ResetBoundaryCondition(self)

    def GetBoundaryCondition(self):
        r"""GetBoundaryCondition(self) -> itkImageBoundaryConditionIUC3"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_GetBoundaryCondition(self)

    def SetUseBoundaryCondition(self, _arg):
        r"""
        SetUseBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_SetUseBoundaryCondition(self, _arg)

    def GetUseBoundaryCondition(self):
        r"""GetUseBoundaryCondition(self) -> bool"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_GetUseBoundaryCondition(self)
    SameDimensionCheck1 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_SameDimensionCheck2
    
    OutputInputEqualityComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_OutputInputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_InputConvertibleToOutputCheck
    
    IntConvertibleToOutputCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_IntConvertibleToOutputCheck
    
    InputEqualityComparable = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_InputEqualityComparable
    
    InputOStreamWritableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_InputOStreamWritableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_cast(obj)

# Register itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass_swigregister(itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass)

def itkDilateObjectMorphologyImageFilterIF2IF2SE2_New():
    return itkDilateObjectMorphologyImageFilterIF2IF2SE2.New()

class itkDilateObjectMorphologyImageFilterIF2IF2SE2(itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIF2IF2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDilateObjectMorphologyImageFilterIF2IF2SE2_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDilateObjectMorphologyImageFilterIF2IF2SE2_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Clone(self)
    KernelGreaterThanComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIF2IF2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIF2IF2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDilateObjectMorphologyImageFilterIF2IF2SE2

        Create a new object of the class itkDilateObjectMorphologyImageFilterIF2IF2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDilateObjectMorphologyImageFilterIF2IF2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDilateObjectMorphologyImageFilterIF2IF2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDilateObjectMorphologyImageFilterIF2IF2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDilateObjectMorphologyImageFilterIF2IF2SE2 in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_swigregister(itkDilateObjectMorphologyImageFilterIF2IF2SE2)

def itkDilateObjectMorphologyImageFilterIF3IF3SE3_New():
    return itkDilateObjectMorphologyImageFilterIF3IF3SE3.New()

class itkDilateObjectMorphologyImageFilterIF3IF3SE3(itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIF3IF3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDilateObjectMorphologyImageFilterIF3IF3SE3_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDilateObjectMorphologyImageFilterIF3IF3SE3_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Clone(self)
    KernelGreaterThanComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIF3IF3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIF3IF3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDilateObjectMorphologyImageFilterIF3IF3SE3

        Create a new object of the class itkDilateObjectMorphologyImageFilterIF3IF3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDilateObjectMorphologyImageFilterIF3IF3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDilateObjectMorphologyImageFilterIF3IF3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDilateObjectMorphologyImageFilterIF3IF3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDilateObjectMorphologyImageFilterIF3IF3SE3 in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_swigregister(itkDilateObjectMorphologyImageFilterIF3IF3SE3)

def itkDilateObjectMorphologyImageFilterISS2ISS2SE2_New():
    return itkDilateObjectMorphologyImageFilterISS2ISS2SE2.New()

class itkDilateObjectMorphologyImageFilterISS2ISS2SE2(itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterISS2ISS2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Clone(self)
    KernelGreaterThanComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterISS2ISS2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterISS2ISS2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDilateObjectMorphologyImageFilterISS2ISS2SE2

        Create a new object of the class itkDilateObjectMorphologyImageFilterISS2ISS2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDilateObjectMorphologyImageFilterISS2ISS2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDilateObjectMorphologyImageFilterISS2ISS2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDilateObjectMorphologyImageFilterISS2ISS2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDilateObjectMorphologyImageFilterISS2ISS2SE2 in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_swigregister(itkDilateObjectMorphologyImageFilterISS2ISS2SE2)

def itkDilateObjectMorphologyImageFilterISS3ISS3SE3_New():
    return itkDilateObjectMorphologyImageFilterISS3ISS3SE3.New()

class itkDilateObjectMorphologyImageFilterISS3ISS3SE3(itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterISS3ISS3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Clone(self)
    KernelGreaterThanComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterISS3ISS3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterISS3ISS3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDilateObjectMorphologyImageFilterISS3ISS3SE3

        Create a new object of the class itkDilateObjectMorphologyImageFilterISS3ISS3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDilateObjectMorphologyImageFilterISS3ISS3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDilateObjectMorphologyImageFilterISS3ISS3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDilateObjectMorphologyImageFilterISS3ISS3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDilateObjectMorphologyImageFilterISS3ISS3SE3 in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_swigregister(itkDilateObjectMorphologyImageFilterISS3ISS3SE3)

def itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_New():
    return itkDilateObjectMorphologyImageFilterIUC2IUC2SE2.New()

class itkDilateObjectMorphologyImageFilterIUC2IUC2SE2(itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIUC2IUC2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Clone(self)
    KernelGreaterThanComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIUC2IUC2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIUC2IUC2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDilateObjectMorphologyImageFilterIUC2IUC2SE2

        Create a new object of the class itkDilateObjectMorphologyImageFilterIUC2IUC2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDilateObjectMorphologyImageFilterIUC2IUC2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDilateObjectMorphologyImageFilterIUC2IUC2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDilateObjectMorphologyImageFilterIUC2IUC2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDilateObjectMorphologyImageFilterIUC2IUC2SE2 in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_swigregister(itkDilateObjectMorphologyImageFilterIUC2IUC2SE2)

def itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_New():
    return itkDilateObjectMorphologyImageFilterIUC3IUC3SE3.New()

class itkDilateObjectMorphologyImageFilterIUC3IUC3SE3(itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass):
    r"""Proxy of C++ itkDilateObjectMorphologyImageFilterIUC3IUC3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Pointer"""
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Clone(self)
    KernelGreaterThanComparableCheck = _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkDilateObjectMorphologyImageFilterPython.delete_itkDilateObjectMorphologyImageFilterIUC3IUC3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDilateObjectMorphologyImageFilterIUC3IUC3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDilateObjectMorphologyImageFilterIUC3IUC3SE3

        Create a new object of the class itkDilateObjectMorphologyImageFilterIUC3IUC3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDilateObjectMorphologyImageFilterIUC3IUC3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDilateObjectMorphologyImageFilterIUC3IUC3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDilateObjectMorphologyImageFilterIUC3IUC3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDilateObjectMorphologyImageFilterIUC3IUC3SE3 in _itkDilateObjectMorphologyImageFilterPython:
_itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_swigregister(itkDilateObjectMorphologyImageFilterIUC3IUC3SE3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def dilate_object_morphology_image_filter(*args: itkt.ImageLike,  kernel: itkt.FlatStructuringElement=..., object_value: int=..., use_boundary_condition: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for DilateObjectMorphologyImageFilter"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'object_value':object_value,'use_boundary_condition':use_boundary_condition }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.DilateObjectMorphologyImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def dilate_object_morphology_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKBinaryMathematicalMorphology.DilateObjectMorphologyImageFilter
    dilate_object_morphology_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    dilate_object_morphology_image_filter.__doc__ = filter_object.__doc__



